# Flex [![Build Status](https://travis-ci.org/alexandrevicenzi/Flex.svg?branch=master)](https://travis-ci.org/alexandrevicenzi/Flex) [![Dependency Status](https://david-dm.org/alexandrevicenzi/Flex.svg)](https://david-dm.org/alexandrevicenzi/Flex) [![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/alexandre-vicenzi/flex?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

The minimalist [Pelican](http://blog.getpelican.com/) theme.

## Note

DON'T send any questions, issues or anything related to Flex to my personal email. They will be IGNORED by now. Your question maybe also is someone else's question. They SHOULD be public, so others can know how to fix configuration problems.

## Features

- Mobile First
- Responsive
- Semantic
- SEO Best Practices
- Open Graph
- Rich Snippets (JSON-LD)
- Related Posts (via [plugin](https://github.com/getpelican/pelican-plugins/tree/master/related_posts) or AddThis)
- Minute read (via [plugin](https://github.com/getpelican/pelican-plugins/tree/master/post_stats)) (new in 2.0)
- [Multiple Code Highlight Styles](https://github.com/alexandrevicenzi/Flex/wiki/Code-Highlight)
- [Translation Support](https://github.com/alexandrevicenzi/Flex/wiki/Translations) (new in 2.0)

## Integrations

- [AddThis](http://www.addthis.com/) Share Buttons and Related Posts
- [Disqus](https://disqus.com/)
- [duoshuo](http://duoshuo.com/) (new in 2.2)
- [Gauges Analytics](http://get.gaug.es/)
- [Google AdSense](https://www.google.com.br/adsense/start/) (new in 2.1)
- [Google Analytics](https://www.google.com/analytics/web/)
- [Google Tag Manager](https://www.google.com/tagmanager/)
- [Piwik Analytics](http://piwik.org/)
- [StatusCake](https://www.statuscake.com/)

## Plugins Support

- [Github Corners](https://github.com/tholman/github-corners) (new in 2.2)
- [I18N Sub-sites](https://github.com/getpelican/pelican-plugins/tree/master/i18n_subsites) (new in 2.0)
- [Minute read](https://github.com/getpelican/pelican-plugins/tree/master/post_stats)) (new in 2.0)
- [Related Posts](https://github.com/getpelican/pelican-plugins/tree/master/related_posts)
- [Representative image](https://github.com/getpelican/pelican-plugins/tree/master/representative_image) (new in 2.2)
- [Neighbors](https://github.com/getpelican/pelican-plugins/tree/master/neighbors) (new in 2.2)

## Install

The recommend way to install is over [pelican-themes](https://github.com/getpelican/pelican-themes).

The `master` branch is the development branch. If you're happy with fresh new things and maybe sometimes (~most of time~) broken things you can clone the `master`, but I would recommend to you to clone a tag branch.

## Documentation

[Go to Wiki](https://github.com/alexandrevicenzi/Flex/wiki)

## Contributing

Always open an issue before sending a PR. Talk about the problem/feature that you want to fix. If it's really a good thing you can submit your PR. If you send an PR without talking about before what it is, you may work for nothing.

As always, if you want something that only make sense to you, just fork Flex and start a new theme.

## Donate

Are you using this theme? Support bug fixes and new features.

**PayPal** - [Click Here](http://bit.ly/flex-paypal)

**BTC** - `1GgoDLWS1HoCkq1HgtpFHzbi5DnDceLGfd`

![BTC](https://github.com/alexandrevicenzi/Flex/blob/master/btc.png)

**DOGE** - `DLXtxaMmyoe4Z8uBcnjTCheAZRsAeWSgyp`

## Live example

You can see how this theme looks like [here](https://blog.alexandrevicenzi.com/flex-pelican-theme.html).

![Screenshot](https://github.com/alexandrevicenzi/Flex/blob/master/screenshot.png)

## Translate

Translate this theme to new languages at [Transifex](https://www.transifex.com/alexandrevicenzi/flex-pelican/).

![Translations](https://github.com/alexandrevicenzi/Flex/blob/master/translation_chart.png)

Read more about [Translation Support](https://github.com/alexandrevicenzi/Flex/wiki/Translations).

## License

MIT
